@@ -1,7 +1,7 @@
 package TestClass;
 
 use Moose;
-use Pinto::Types qw(File Dir Uri IO AuthorID Vers);
+use Pinto::Types qw(File Dir Uri IO AuthorID StackName Vers);
 
 #-----------------------------------------------------------------------------
 
@@ -35,6 +35,12 @@ has author => (
     coerce => 1,
 );
 
+has stack => (
+    is  => 'rw',
+    isa => StackName,
+    coerce => 1,
+);
+
 has version => (
     is  => 'rw',
     isa => Vers,
